# Code of Conduct

Everyone participating in this project is governed by the CSDMS [Code of Conduct](https://github.com/csdms/project/blob/main/CODE-OF-CONDUCT.md).
By participating, you are expected to uphold this code.
